package mi.hdm.recipes;

import mi.hdm.exceptions.InvalidCategoryException;

public class Category {

    private final String name;
    private final String colourCode; //0x für Hexzahlen


    public Category (String name, int colourCode) {
        if(name == null || name.equals("")) {
            throw new InvalidCategoryException("Can not add category with name " + name);
        }
        if(colourCode < 0 || colourCode > 0xFFFFFF) {
            throw new InvalidCategoryException("Can not add category with color code " + colourCode);
        }
        this.name = name;
        this.colourCode = CategoryManager.numberToColorCodeString(colourCode);
    }


    public String getColourCode() {
        return colourCode;
    }

    public String getName() {
        return name;
    }

    @Override
    public boolean equals(Object o){
        if (o instanceof Category c) {
            return this.name.equals(c.getName()) && this.colourCode.equals(c.getColourCode());
        }
        return false;
    }

    @Override
    public String toString() {
        return String.format("Category %s with color code %s", name, colourCode);
    }

}
